=================
ankiapp_easy_deck
=================

Overview
--------

Easy way to make an AnkiApp deck.

Installation
------------

To install ankiapp_easy_deck, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install ankiapp_easy_deck

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/ankiapp-easy-deck/#files>`_
* `Source <https://github.com/johannes-programming/ankiapp_easy_deck>`_

Credits
-------
- Author: Johannes
- Email: johannes-programming@posteo.org

Thank you for using ankiapp_easy_deck!
